[PATCH 06/15] staging: wlan-ng: do not return -ENOSYS

Sergio Paracuellos sergio.paracuellos at gmail.com
Sun Oct 9 15:10:23 UTC 2016


Fixed coding style issue by replacing ENOSYS with EINVAL.

This patch fix the following checkpatch.pl warnings in p80211netdev.c:
WARNING: ENOSYS means 'invalid syscall nr' and nothing else

Signed-off-by: Sergio Paracuellos <sergio.paracuellos at gmail.com>
---
 drivers/staging/wlan-ng/p80211netdev.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/staging/wlan-ng/p80211netdev.c b/drivers/staging/wlan-ng/p80211netdev.c
index fb28d8f..656033a 100644
--- a/drivers/staging/wlan-ng/p80211netdev.c
+++ b/drivers/staging/wlan-ng/p80211netdev.c
@@ -532,7 +532,7 @@ static int p80211netdev_ethtool(struct wlandevice *wlandev,
  *		-ETIME	p80211 cmd timed out (MSD may have its own timers)
  *		-EFAULT memory fault copying msg from user buffer
  *		-ENOMEM unable to allocate kernel msg buffer
  *		-ENOSYS	bad magic, it the cmd really for us?
  *		-EintR	sleeping on cmd, awakened by signal, cmd cancelled.
  *
  * Call Context:
@@ -560,7 +560,7 @@ static int p80211knetdev_do_ioctl(struct net_device *dev,
 
 	/* Test the magic, assume ifr is good if it's there */
 	if (req->magic != P80211_IOCTL_MAGIC) {
-		result = -ENOSYS;
+		result = -EINVAL;
 		goto bail;
 	}
 
@@ -568,7 +568,7 @@ static int p80211knetdev_do_ioctl(struct net_device *dev,
 		result = 0;
 		goto bail;
 	} else if (cmd != P80211_IFREQ) {
-		result = -ENOSYS;
+		result = -EINVAL;
 		goto bail;
 	}
 
@@ -532,7 +532,7 @@ static int p80211netdev_ethtool(struct wlandevice *wlandev,
  *		-EFAULT memory fault copying msg from user buffer
  *		-ENOMEM unable to allocate kernel msg buffer
- *		-ENOSYS	bad magic, it the cmd really for us?
+ *		-EINVAL	bad magic, it the cmd really for us?
  *		-EintR	sleeping on cmd, awakened by signal, cmd cancelled.
  *
-- 
1.9.1



More information about the devel mailing list